pub struct RowidAliasHint {
pub qualifier: Option<String>,
pub column: String,
}Expand description
Schema hint that a visible table column is an alias for SQLite’s hidden
rowid, as with INTEGER PRIMARY KEY.
Fields
qualifier: Option<String>Optional table name or query alias qualifier accepted for the column.
column: StringVisible column name that aliases the rowid.
Implementations