pub enum CompoundOrderByError {
ColumnNotFound {
name: String,
span: Span,
},
IndexOutOfRange {
index: usize,
num_columns: usize,
span: Span,
},
IndexZeroOrNegative {
value: i64,
span: Span,
},
ExpressionNotAllowed {
span: Span,
},
}Expand description
Errors during compound ORDER BY resolution.
Variants
ColumnNotFound
The referenced column name was not found in any SELECT’s output aliases.
IndexOutOfRange
A numeric column index is out of range (1-based in SQL, but converted).
IndexZeroOrNegative
A zero or negative numeric column index.
ExpressionNotAllowed
An expression (e.g. a+1) is not allowed in compound ORDER BY.